@@ -25,8 +25,10 @@ boa_smooth <- online(
     y = matrix(y),
     tau = prob_grid,
     experts = experts,
-    p_smooth_lambda = 50,
-    p_smooth_ndiff = 2,
+    p_smooth_pr = list(
+        lambda = 50,
+        diff = 2
+    ),
     trace = FALSE
 )
 
@@ -34,8 +36,10 @@ boa_smooth_sobol <- online(
     y = matrix(y),
     tau = prob_grid,
     experts = experts,
-    p_smooth_lambda = 50,
-    p_smooth_ndiff = 1.5,
+    p_smooth_pr = list(
+        lambda = 50,
+        diff = 1.5
+    ),
     trace = FALSE
 )
 
